summaryrefslogtreecommitdiff
path: root/bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx
diff options
context:
space:
mode:
authorTor Lillqvist <tml@collabora.com>2013-10-02 21:56:10 +0300
committerTor Lillqvist <tml@collabora.com>2013-10-02 21:57:42 +0300
commite036d4b706685b995a497808e357b9fd2eb9d965 (patch)
treee1981081ae4b49913db9923795fb43236a48ab8a /bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx
parent4d646780dee68d319b0b801111e99cb2eab03a5d (diff)
Spell "indices" correctly
Change-Id: I63b1de195bf2f3f8bfd185181f48b1520cdd849f
Diffstat (limited to 'bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx')
-rw-r--r--bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx28
1 files changed, 14 insertions, 14 deletions
diff --git a/bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx b/bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx
index f60afae62102..20d534c1529b 100644
--- a/bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx
+++ b/bridges/source/cpp_uno/gcc3_aix_powerpc/cpp2uno.cxx
@@ -88,13 +88,13 @@ static typelib_TypeClass cpp2uno_call(
void ** pUnoArgs = (void **)__builtin_alloca( 4 * sizeof(void *) * nParams );
void ** pCppArgs = pUnoArgs + nParams;
- // indizes of values this have to be converted (interface conversion cpp<=>uno)
- sal_Int32 * pTempIndizes = (sal_Int32 *)(pUnoArgs + (2 * nParams));
+ // indices of values this have to be converted (interface conversion cpp<=>uno)
+ sal_Int32 * pTempIndices = (sal_Int32 *)(pUnoArgs + (2 * nParams));
// type descriptions for reconversions
typelib_TypeDescription ** ppTempParamTypeDescr = (typelib_TypeDescription **)(pUnoArgs + (3 * nParams));
- sal_Int32 nTempIndizes = 0;
+ sal_Int32 nTempIndices = 0;
for ( sal_Int32 nPos = 0; nPos < nParams; ++nPos )
{
@@ -206,9 +206,9 @@ static typelib_TypeClass cpp2uno_call(
{
// uno out is unconstructed mem!
pUnoArgs[nPos] = __builtin_alloca( pParamTypeDescr->nSize );
- pTempIndizes[nTempIndizes] = nPos;
+ pTempIndices[nTempIndices] = nPos;
// will be released at reconversion
- ppTempParamTypeDescr[nTempIndizes++] = pParamTypeDescr;
+ ppTempParamTypeDescr[nTempIndices++] = pParamTypeDescr;
}
// is in/inout
else if (bridges::cpp_uno::shared::relatesToInterfaceType( pParamTypeDescr ))
@@ -216,9 +216,9 @@ static typelib_TypeClass cpp2uno_call(
uno_copyAndConvertData( pUnoArgs[nPos] = __builtin_alloca( pParamTypeDescr->nSize ),
pCppStack, pParamTypeDescr,
pThis->getBridge()->getCpp2Uno() );
- pTempIndizes[nTempIndizes] = nPos; // has to be reconverted
+ pTempIndices[nTempIndices] = nPos; // has to be reconverted
// will be released at reconversion
- ppTempParamTypeDescr[nTempIndizes++] = pParamTypeDescr;
+ ppTempParamTypeDescr[nTempIndices++] = pParamTypeDescr;
}
else // direct way
{
@@ -241,13 +241,13 @@ static typelib_TypeClass cpp2uno_call(
if (pUnoExc)
{
// destruct temporary in/inout params
- for ( ; nTempIndizes--; )
+ for ( ; nTempIndices--; )
{
- sal_Int32 nIndex = pTempIndizes[nTempIndizes];
+ sal_Int32 nIndex = pTempIndices[nTempIndices];
if (pParams[nIndex].bIn) // is in/inout => was constructed
- uno_destructData( pUnoArgs[nIndex], ppTempParamTypeDescr[nTempIndizes], 0 );
- TYPELIB_DANGER_RELEASE( ppTempParamTypeDescr[nTempIndizes] );
+ uno_destructData( pUnoArgs[nIndex], ppTempParamTypeDescr[nTempIndices], 0 );
+ TYPELIB_DANGER_RELEASE( ppTempParamTypeDescr[nTempIndices] );
}
if (pReturnTypeDescr)
TYPELIB_DANGER_RELEASE( pReturnTypeDescr );
@@ -261,10 +261,10 @@ static typelib_TypeClass cpp2uno_call(
else // else no exception occurred...
{
// temporary params
- for ( ; nTempIndizes--; )
+ for ( ; nTempIndices--; )
{
- sal_Int32 nIndex = pTempIndizes[nTempIndizes];
- typelib_TypeDescription * pParamTypeDescr = ppTempParamTypeDescr[nTempIndizes];
+ sal_Int32 nIndex = pTempIndices[nTempIndices];
+ typelib_TypeDescription * pParamTypeDescr = ppTempParamTypeDescr[nTempIndices];
if (pParams[nIndex].bOut) // inout/out
{